@@ -21,7 +21,6 @@ import sys
 
 from uadm.uadmcore import *
 
-#if __name__ == "__main__":
 def run(args = []):
     cmd_list = [
         "apt-get update",
@@ -32,3 +31,5 @@ def run(args = []):
 
     exec_cmd_list(cmd_list)
 
+if __name__ == "__main__":
+    run(sys.argv)
